library(Pmetrics)
setwd("...") 
list.files()

#establish error model
ERRrun(data="datav2.csv",model="model2.txt",ode = -8, tol = 0.001, salt=1, cycles = 10000, search = "extensive",xdev = 5, auto = T, intern = F, silent = F, overwrite = F,nocheck = F)

#run NPAG analysis
NPrun(data="datav2.csv",model="model2.txt",ode = -8, tol = 0.001, salt=1, cycles = 10000,icen = "mean", auto = T, intern = F, silent = F, overwrite = F,nocheck = F,parallel=F)

###############################################################################
###############################################################################
##############################################################################

#plot obs vs pred from NPAG analysis, Figure 2
z<-subset(NPAGout$op,NPAGout$op$outeq==1&NPAGout$op$icen=="mean"&NPAGout$op$pred.type=="post"&!(is.na(NPAGout$op$obs)))[,c(2:4)]
z1<-subset(NPAGout$op,NPAGout$op$outeq==2&NPAGout$op$icen=="mean"&NPAGout$op$pred.type=="post"&!(is.na(NPAGout$op$obs)))[,c(2:4)]
setwd("...")
tiff('figure2.tiff', width = 1350*300/75, height = 830*300/75, res = 300)
par(mfrow = c(1,2),mar = c(6, 6, 4.1, 2.1))
plot(z$obs,z$pred,cex=2,main="Posterior prediction, Maternal",ylab="Observed",xlab="Predicted",col="blue",cex.main = 2,cex.lab = 1.4,cex.axis = 0.8)
abline(coef = c(0, 1),lty=2,lwd=2)
text(x=3, y=40, labels="R-squared = 1",cex = 1.2,pos = 4)
text(x=3, y=39, labels="Inter = -0.00702 (95% CI -0.0286 to 0.0146)",cex = 1.2,pos = 4)
text(x=3, y=38, labels="Slope = 1 (95% CI 0.999 to 1)",cex = 1.2,pos = 4)
text(x=3, y=37, labels="Bias = 0.264",cex = 1.2,pos = 4)
text(x=3, y=36, labels="Imprecision = 1.91",cex = 1.2,pos = 4)
plot(z1$obs,z1$pred,cex=2,main="Posterior prediction, Fetal",ylab="Observed",xlab="Predicted",col="blue",cex.main = 2,cex.lab = 1.4,cex.axis = 0.8)
abline(coef = c(0, 1),lty=2,lwd=2)
text(x=4, y=25, labels="R-squared = 1",cex = 1.2,pos = 4)
text(x=4, y=24.4, labels="Inter = -0.000154 (95% CI -0.000726 to 0.00103)",cex = 1.2,pos = 4)
text(x=4, y=23.8, labels="Slope = 1 (95% CI 1 to 1)",cex = 1.2,pos = 4)
text(x=4, y=23.2, labels="Bias = 0.00177",cex = 1.2,pos = 4)
text(x=4, y=22.6, labels="Imprecision = 0.00215",cex = 1.2,pos = 4)
dev.off()

#simulations from best model
library(Pmetrics)
setwd("...")
PMload(...)
setwd("...")
SIMrun(poppar=...,data="....csv",model="model2.txt",limits=NA,nsim=1000)
simdata <- SIMparse("sim*.txt",combine=T)

#mother and neonate concentrations extracted from Pmetrics sims
neodata<-simdata$obs
write.csv(neodata,"...\\mothneoconcALL.csv") 

#neonate amt extract from Pmetrics sims to be used as inits
neodata<-subset(simdata$amt,simdata$amt$comp==2)
write.csv(neodata,"...\\neoinitALL.csv") 

#simulated paras from Pmetrics so neonate vd can be reused when sim for neonate after birth
paramspk<-simdata$parValues
write.csv(paramspk,"...\\paramspkALL.csv") 

#simulations for neonate after birth
library(plyr)

#get neonate concentrations from Pmetrics sims which will be used during AUC calculations before birth
modneoconcdata<-read.csv("...\\mothneoconcALL.csv",stringsAsFactors = F) 
neoconcdata<-subset(modneoconcdata,modneoconcdata$outeq==2)

#get neo inits from above to be used as initial conditions for sims after birth
neodata<-read.csv("...\\neoinitALL.csv",stringsAsFactors = F) 

#set possible birth times at hourly intervals
hourt<-c(2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48)

hourtcycle<-length(hourt)
for (j in 1:hourtcycle) {
library(plyr)
#average weights for babies at birth for gestational ages below (ga), literature value  
weight<-c(2029,2266,2512,2754,2981,3181,3350,3486)/1000
ga<-c(33,34,35,36,37,38,39,40)
weightcycle<-length(weight)
for (k in 1:weightcycle) {
pma<-0/7+ga[k]
#average creatinine for babies at birth for gestational ages, literature value  
creat<-ifelse(ga[k]<25,106.5/88.4,
ifelse(ga[k]<27,103.9/88.4,
ifelse(ga[k]<29,99.1/88.4,
ifelse(ga[k]<33,80/88.4,
ifelse(ga[k]<38,80/88.4,
77/88.4)))))
#bring back Pmetrics estimated VD for neonates into calculations
vc<-read.csv("...\\paramspkALL.csv")[,4] 
#frymoer vanco cl IIV and popmodel equation
cliiv<-rnorm(length(vc),0,0.216)
cl<-(0.345*((weight[k]/2.9)^0.75)*(1/(1+(pma/34.8)^-4.53))*(1/creat)^0.267)*exp(cliiv)
plist <-data.frame(cl=cl,vc=vc)
state <-data.frame(y=subset(neodata,neodata$time==hourt[j])[,4])

library(deSolve)
setwd("...")
system("R CMD SHLIB modelFME2.c")
dyn.load(paste("modelFME2", .Platform$dynlib.ext, sep = ""))

#simplified IDODS sim function
model <- function(pars, times=seq(0,48, by = 0.1)) {
state <- c(unlist(state[i,]))
return(ode(y = state, times = times, func = "derivs", parms = c(unlist(plist[i,])),dllname = "modelFME2",
method="lsoda",rtol = 1e-8,atol =1e-8,hmax=0.1,initfunc = "initmod", nout=1,outnames=c("cp")))
}

modelout <- list()
for (i in 1:nrow(plist))
modelout[[i]] <- model(plist)
fullcourse<-data.frame(modelout)

#extract neonate blood conc from sim after birth 
bloodlevels <-cbind(time=seq(0,48, by = 0.1),fullcourse[, grepl("^cp", colnames(fullcourse))])
bloodlevels<-bloodlevels[-c(1),]

#extract neonate blood conc from Pmetrics sim before birth 
pmetneoconcpre <-matrix(subset(neoconcdata,neoconcdata$time<=hourt[j])[,4],ncol=length(vc))
pmetneoconcpre<-rbind(rep(0,length(vc)),pmetneoconcpre)
pmetneoconc<-as.data.frame(cbind(time=c(0,2:hourt[j]),pmetneoconcpre), stringsAsFactors=FALSE)
colnames(pmetneoconc)<-colnames(bloodlevels)
bloodlevels$time<-bloodlevels$time+hourt[j]

#bind concentraions before and after birth
bloodlevels<-rbind(pmetneoconc,bloodlevels)

troughtime<-bloodlevels$time[max(which(bloodlevels$time<24))]
datatoplot<-data.frame(time=bloodlevels$time,cp=bloodlevels$cp.15)
plot(datatoplot,type="l")
points(subset(datatoplot,datatoplot$time==troughtime),col="red")

#set up data to calc AUC day 1 and 2
AUCday1 <-subset(bloodlevels,bloodlevels$time>0&bloodlevels$time<=24)[,-1]
AUCday2 <-subset(bloodlevels,bloodlevels$time>24&bloodlevels$time<=48)[,-1]

#get "troughs" at birth
TROUGHS <-subset(bloodlevels ,bloodlevels$time==troughtime)[,-1]
troughover15<-sum(ifelse(TROUGHS>=15,1,0))/length(vc)

MTIME1.1 <-subset(bloodlevels,bloodlevels$time>0&bloodlevels$time<=24)[,1]
MTIME1.2 <-subset(bloodlevels,bloodlevels$time>24&bloodlevels$time<=48)[,1]

#calc AUCs day 1 and 2 in neonate
SAUCday1 <-(apply(AUCday1,2,function(x) sum(diff(MTIME1.1)*(x[-1]+x[-length(x)]))/2 ))
SAUCday2 <-(apply(AUCday2,2,function(x) sum(diff(MTIME1.2)*(x[-1]+x[-length(x)]))/2 ))

#calc AUCs below and over certain cutoffs and between 400 and 600
day1over600<-round_any(length(which(as.numeric(unname(unlist(SAUCday1)))>600))/length(vc),0.001)*100
day2over600<-round_any(length(which(as.numeric(unname(unlist(SAUCday2)))>600))/length(vc),0.001)*100
day1bellow400<-round_any(length(which(as.numeric(unname(unlist(SAUCday1)))<400))/length(vc),0.001)*100
day2bellow400<-round_any(length(which(as.numeric(unname(unlist(SAUCday2)))<400))/length(vc),0.001)*100
day1over30<-round_any(length(which(as.numeric(unname(unlist(SAUCday1)))>39.1))/length(vc),0.001)*100
day2over30<-round_any(length(which(as.numeric(unname(unlist(SAUCday2)))>39.1))/length(vc),0.001)*100
day1over800<-round_any(length(which(as.numeric(unname(unlist(SAUCday1)))>800))/length(vc),0.001)*100
day2over800<-round_any(length(which(as.numeric(unname(unlist(SAUCday2)))>800))/length(vc),0.001)*100
day1<-100-(day1over600+day1bellow400)
day2<-100-(day2over600+day2bellow400)

#bind data for output, little messy but gets work done
otdata<-cbind(day1over30,day2over30,day1,day2,day1over600,day2over600,day1over800,day2over800,day1bellow400,day2bellow400,hourt[j],weight[k],ga[k],round_any(creat,0.01),8000,round_any(quantile(SAUCday1,probs=0.5),0.01),round_any(quantile(SAUCday2,probs=0.5),0.01),round_any(quantile(SAUCday1,probs=0.9),0.01),round_any(quantile(SAUCday2,probs=0.9),0.01),round_any(quantile(state$y/weight[k],probs=0.25),0.01),round_any(quantile(state$y/weight[k],probs=0.5),0.01),round_any(quantile(state$y/weight[k],probs=0.75),0.01),round_any(quantile(state$y/weight[k],probs=0.9),0.01),troughover15)
colnames(otdata)<-c("day1over39","day2over39","day1","day2","day1.600","day2.600","day1.800","day2.800","day1.400","day2.400","hour","weight","ga","creat","dose","medday1",	"medday2",	"X90thday1",	"X90thday2","mgkgdose25",	"mgkgdose50",	"mgkgdose75",	"mgkgdose90","troughover15")
res<-read.csv("...\\resAUCser.csv")[,-c(1)]
res<-rbind(res,otdata)
write.csv(res,"...\\resAUCser.csv")}}


########################################################
########################################################
################TILE PLOTTING###########################
#plot figure using all data for manuscript I generated
plotdata<-read.csv("...\\resAUCser.csv")
tiledata<-read.csv("...\\resAUCmgkg.csv")

library(ggplot2)
library(dplyr)
library(hrbrthemes)
library(viridis)
library(plyr)
library(ggrepel)

data <- plotdata[,c(2,12,14,16,25)]
names(data)
data<-subset(data,data$hour %in% seq(2,40,2))

tdata <- tiledata[,c(2,4,5,6)]
tdata<-subset(tdata,tdata$hour %in% seq(2,40,2))
data<-cbind(data,mgkgdose=tdata[,c(4)])
data$dayname<-"Day 1 exposure"
colnames(data)<-c("day.600","hour","ga","dose","troughover15","mgkgdose","dayname")
findata<-data
findata$troughover15<-round_any(findata$troughover15*100,0.1)
findata<-findata[order(findata$dose, decreasing = TRUE),]
findata<-subset(findata,findata$dayname=="Day 1 exposure")
summary(findata)

m4 <- findata %>%
mutate(mgkgdosefactor=cut(mgkgdose,breaks=c(-1,1,10,20,30,max(mgkgdose,na.rm=T)),
labels=c("< 1%","1% - 10%","10% - 20%","20% - 30%","> 30%"))) %>%
mutate(troughover15factor=cut(troughover15,breaks=c(-1,10,20,30,max(troughover15,na.rm=T)),labels=c("1% - 10%","10% - 20%","20% - 30%","> 30%"))) %>%
mutate(mgkgdosefactor=factor(as.character(mgkgdosefactor),levels=rev(levels(mgkgdosefactor)))) %>%
mutate(troughover15factor=factor(as.character(troughover15factor),levels=rev(levels(troughover15factor))))

m4$day.600<-ifelse(m4$day.600<90,sprintf("%.1f", round_any(m4$day.600,0.1)),"")
m4$dose<-paste0(as.character(m4$dose)," mg")
m4$dose<-ifelse(m4$dose=="8000 mg","Population",m4$dose)

setwd("...")
tiff('Tile.tiff', width = 1350*300/75, height = 830*300/75, res = 300)

p<-ggplot(m4,aes(x=hour,y=ga,fill=mgkgdosefactor))+
geom_tile(colour="darkgrey",size=0.2)+
guides(fill=guide_legend(title="% newborns with\n > 30 mg/kg",override.aes = list(shape = NA)))+
labs(y="Gestational Age (weeks)\n",x=paste("\nTime of birth after first dose of Vancomycin (hours)"))+
scale_y_continuous(limits=c(32.5, 41),breaks=c(33,34,35,36,37,38,39,40))+
scale_x_continuous(expand=c(0,0),breaks=seq(2,40,4))+
scale_fill_manual(values=c("#525252","#878787","#a3a3a3","#d1d1d1","#ffffff"))+
facet_wrap(~ dose)+
theme_grey(base_size=10)+
theme(
plot.title =element_text(size=24), 
axis.title.x=element_text(size=22), 
axis.title.y=element_text(size=22),
axis.text.y=element_text(size=16),
axis.text.x=element_text(size=16),
legend.position="bottom",legend.direction = "horizontal",legend.key.size =unit(1,"cm"),
legend.key.width = unit(1,"cm"),
legend.text = element_text(size=12),
legend.title = element_text(size=15),
legend.key = element_rect(fill = "white"),
strip.text.x = element_text(size = 18))+
geom_text(aes(label = day.600),size=4,hjust = -0.9,vjust = 0.5, nudge_y = -0.8,angle = 90)
findata2<-filter(m4, m4$troughover15>10&(m4$hour %in% c(20,22,24)))
p + geom_point(data = findata2,aes(shape = troughover15factor),size = 3)+
guides(shape=guide_legend(title="% newborns with\n trough > 15 mg/L",override.aes = list(size = 5)))+
scale_shape_manual(values=c(0,1,2))
dev.off()



########################################################
########################################################
################PLOTTING for AUC >600 AND >800 TOGETHER#


plotdata<-read.csv("...\\resAUCser.csv")
unique(plotdata$dose)
plotdataDAY1<-subset(plotdata,plotdata$hour<=24)
plotdataDAY2<-subset(plotdata,plotdata$hour>24)
plotdataDAY1600<-subset(plotdataDAY1,plotdataDAY1$day1.600>10)
plotdataDAY1800<-subset(plotdataDAY1,plotdataDAY1$day1.800>10)
plotdataDAY2600<-subset(plotdataDAY2,plotdataDAY2$day2.600>10)
plotdataDAY2800<-subset(plotdataDAY2,plotdataDAY2$day2.800>10)
plotdataall<-rbind(plotdataDAY1600,plotdataDAY1800,plotdataDAY2600,plotdataDAY2800)
plotdataall<-rbind(plotdataDAY1600,plotdataDAY1800,plotdataDAY2600,plotdataDAY2800)

#600
data <- plotdataall[,c(6,12,14,16,25)]
names(data)
data<-subset(data,data$hour %in% sort(c(seq(2,24,2))))
data$dayname<-"Day 1 exposure"
data$troughover15<-round_any(data$troughover15*100,0.1)
data$target<-600
data2 <- plotdataall[,c(7,12,14,16,25)]
names(data2)
data2<-subset(data2,data2$hour %in% sort(c(seq(26,40,2))))
data2$dayname<-"Day 2 exposure"
data2$troughover15<-round_any(data2$troughover15*100,0.1)
data2$target<-600

#800
data3 <- plotdataall[,c(8,12,14,16,25)]
names(data3)
data3<-subset(data3,data3$hour %in% sort(c(seq(2,24,2))))
data3$dayname<-"Day 1 exposure"
data3$troughover15<-round_any(data3$troughover15*100,0.1)
data3$target<-800
data4 <- plotdataall[,c(9,12,14,16,25)]
names(data4)
data4<-subset(data4,data4$hour %in% sort(c(seq(26,40,2))))
data4$dayname<-"Day 2 exposure"
data4$troughover15<-round_any(data4$troughover15*100,0.1)
data4$target<-800

colnames(data)<-c("day.600","hour","ga","dose","troughover15","dayname","target")
colnames(data2)<-c("day.600","hour","ga","dose","troughover15","dayname","target")
colnames(data3)<-c("day.600","hour","ga","dose","troughover15","dayname","target")
colnames(data4)<-c("day.600","hour","ga","dose","troughover15","dayname","target")
findata<-rbind(data,data2,data3,data4)
findata<-findata[order(findata$dose, decreasing = TRUE),]
findata$dose<-paste0(findata$dayname,", ",findata$dose," mg")
findata$dose<-ifelse(findata$dose=="Day 2 exposure, 8000 mg","Day 2 exposure, Population",findata$dose)
findata$dose<-ifelse(findata$dose=="Day 1 exposure, 2000 mg","A, Day 1 exposure, 2000 mg",
ifelse(findata$dose=="Day 2 exposure, 1250 mg","B, Day 2 exposure, 1250 mg",
ifelse(findata$dose=="Day 2 exposure, 1500 mg","C, Day 2 exposure, 1500 mg",
ifelse(findata$dose=="Day 2 exposure, 1750 mg","D, Day 2 exposure, 1750 mg",
ifelse(findata$dose=="Day 2 exposure, 2000 mg","E, Day 2 exposure, 2000 mg","F, Day 2 exposure, Population")))))

setwd("...")
tiff('figure4.tiff', width = 1200*300/75, height = 900*300/75, res = 300)
findata$circsize<-ifelse(findata$day.600<=20,20,ifelse(findata$day.600<=29.99,31,40))

findata %>%
arrange(desc(target)) %>%
mutate(target = factor(target)) %>%
ggplot(aes(x=hour, y=ga, size=day.600, fill=target)) +
geom_point(alpha=0.5, shape=23) +
scale_size_binned(range=c(0,11),breaks = waiver(),name="PTA of AUC > Target (%)") +
theme_ipsum() +
facet_wrap(~dose, scales = "free_x") +
scale_fill_manual(values=c("white","black"))+
scale_y_continuous(limits=c(32.5, 40.5),breaks=c(33,34,35,36,37,38,39,40))+
theme(
strip.text = element_text(size=15),
plot.title =element_text(size=24), 
axis.title.x=element_text(size=21),  
axis.title.y=element_text(size=21),
axis.text.y=element_text(size=18),
axis.text.x=element_text(size=18),
legend.position="bottom",legend.box = "horizontal",legend.key.size =unit(1,"cm"),legend.title.align=1,
legend.key.width = unit(1,"cm"),
legend.text = element_text(size=12),
legend.title = element_text(size=15,vjust=0.8),
panel.grid.major = element_line(colour="lightgrey"),
panel.grid.minor = element_line(colour="lightgrey")) +
xlab(paste("\nTime of birth after first dose of Vancomycin (hours)                                     \n")) +
ylab("Gestational Age (weeks)                     \n") +
guides(fill = guide_legend(override.aes = list(size=15),title = paste("AUC Target\n (mg*h/L)"),label.position="bottom",title.position="left"))+
scale_x_continuous(breaks=c(20,22,24,26,28,30,32,34,36,38,40))
dev.off()

#Mother PTA
df2<-plotdata1
names(df2)
p3<-df2 %>% mutate(dose = factor(dose)) %>%
ggplot(aes(x=numdose, y=pdi.mean, group=dose, color=dose)) + 
geom_line(size=1.3) +
geom_point()+
geom_errorbar(aes(ymin=pdi.mean-pdi.sd, ymax=pdi.mean+pdi.sd), width=.2,size=1.3,
position=position_dodge(0.05))+
scale_fill_viridis(discrete=TRUE, guide="legend", option="D")+ylim(0,1500)+
labs(title="Figure 1. Maternal Vancomycin Exposure, q8h regimens ", x="\nTotal Number of Doses Administered", y = expression("AUC "[0-24]*" | AUC "[24-48]*" (mg*h/L)"))+
theme_classic() +
scale_color_manual(values=c('#999999','#689200','#E69F00'))+
labs(color = "Dose (mg)")+
theme(
plot.title =element_text(size=24), 
axis.title.x=element_text(size=22),  
axis.title.y=element_text(size=22),
axis.text.y=element_text(size=16),
axis.text.x=element_text(size=16),
legend.position="bottom",legend.direction = "horizontal",legend.key.size =unit(3,"cm"),
legend.key.width = unit(3,"cm"),
legend.text = element_text(size=12),
legend.title = element_text(size=15)) 
margin = theme(plot.margin = unit(rep(0.5,4), "cm"))
p<-list(p3,p1,p2)
grid.arrange(grobs = lapply(p, "+", margin),nrow = 1, ncol =3)